@@ -110,6 +110,12 @@ def ssl_certificate_validation_disabled():
         os.environ.get('LP_DISABLE_SSL_CERTIFICATE_VALIDATION', False))
 
 
+if os.path.exists('/etc/ssl/certs/ca-certificates.crt'):
+    SYSTEM_CA_CERTS = '/etc/ssl/certs/ca-certificates.crt'
+else:
+    from httplib2 import CA_CERTS as SYSTEM_CA_CERTS
+
+
 class RestfulHttp(Http):
     """An Http subclass with some custom behavior.
 
@@ -125,7 +131,8 @@ class RestfulHttp(Http):
         cert_disabled = ssl_certificate_validation_disabled()
         super(RestfulHttp, self).__init__(
             cache, timeout, proxy_info,
-            disable_ssl_certificate_validation=cert_disabled)
+            disable_ssl_certificate_validation=cert_disabled,
+            ca_certs=SYSTEM_CA_CERTS)
         self.authorizer = authorizer
         if self.authorizer is not None:
             self.authorizer.authorizeSession(self)
