@@ -21,7 +21,9 @@
 
 from ConfigParser import SafeConfigParser
 import os
+import platform
 import stat
+import socket
 # Work around relative import behavior.  The below is equivalent to
 # from oauth import oauth
 oauth = __import__('oauth.oauth', {}).oauth
@@ -37,20 +39,33 @@ __all__ = [
     'AccessToken',
     'Consumer',
     'OAuthAuthorizer',
+    'SystemWideConsumer',
     ]
 
 
 CREDENTIALS_FILE_VERSION = '1'
 
 
-# These two classes are provided for convenience (so applications don't need
-# to import from oauth.oauth), and to provide a default argument
-# for secret.
+# These two classes are provided for convenience (so applications
+# don't need to import from oauth.oauth), and to provide
+# lazr.restfulclient-specific enhancements like a default argument for
+# secret (which shouldn't be used), and an application name separate
+# from the consumer key.
 class Consumer(oauth.OAuthConsumer):
     """An OAuth consumer (application)."""
 
-    def __init__(self, key, secret=''):
+    def __init__(self, key, secret='', application_name=None):
+        """Initialize
+
+        :param key: The OAuth consumer key
+        :param secret: The OAuth consumer secret. Don't use this. It's
+            a misfeature, and lazr.restful doesn't expect it.
+        :param application_name: An application name, if different
+            from the consumer key. If present, this will be used in
+            the User-Agent header.
+        """
         OAuthConsumer.__init__(self, key, secret)
+        self.application_name = application_name
 
 
 class AccessToken(oauth.OAuthToken):
@@ -61,14 +76,56 @@ class AccessToken(oauth.OAuthToken):
         self.context = context
 
 
+class SystemWideConsumer(Consumer):
+    """A consumer associated with the logged-in user rather than an app.
+
+    This can be used to share a single OAuth token among multiple
+    desktop applications. The OAuth consumer key will be derived from
+    system information (platform and hostname).
+    """
+    KEY_FORMAT = "System-wide: %s (%s)"
+
+    def __init__(self, application_name, secret=''):
+        """Constructor.
+
+        :param application_name: An application name. This will be
+            used in the User-Agent header.
+        :param secret: The OAuth consumer secret. Don't use this. It's
+            a misfeature, and lazr.restful doesn't expect it.
+        """
+        super(SystemWideConsumer, self).__init__(
+            self.consumer_key, secret, application_name)
+
+    @property
+    def consumer_key(self):
+        """The system-wide OAuth consumer key for this computer.
+
+        This key identifies the platform and the computer's
+        hostname. It does not identify the active user.
+        """
+        try:
+            distname, version, release_id = platform.linux_distribution()
+        except Exception, e:
+            # This can happen in pre-2.6 versions of Python. We don't
+            # use platform.dist() because it looks like old versions
+            # of dist can give inconsistent answers on a single
+            # computer.
+            distname = ''
+        if distname == '':
+            distname = platform.system() # (eg. "Windows")
+        return self.KEY_FORMAT % (distname, socket.gethostname())
+
+
 class OAuthAuthorizer(HttpAuthorizer):
     """A client that signs every outgoing request with OAuth credentials."""
 
     def __init__(self, consumer_name=None, consumer_secret='',
-                 access_token=None, oauth_realm="OAuth"):
+                 access_token=None, oauth_realm="OAuth",
+                 application_name=None):
         self.consumer = None
         if consumer_name is not None:
-            self.consumer = Consumer(consumer_name, consumer_secret)
+            self.consumer = Consumer(
+                consumer_name, consumer_secret, application_name)
         self.access_token = access_token
         self.oauth_realm = oauth_realm
 
@@ -78,9 +135,13 @@ class OAuthAuthorizer(HttpAuthorizer):
 
         In this case, the OAuth consumer name.
         """
+        params = {}
         if self.consumer is None:
-            return {}
-        return {'oauth_consumer' : self.consumer.key}
+            return params
+        params['oauth_consumer'] = self.consumer.key
+        if self.consumer.application_name is not None:
+            params['application'] =  self.consumer.application_name
+        return params
 
     def load(self, readable_file):
         """Load credentials from a file-like object.
