@@ -29,7 +29,6 @@ __all__ = [
     ]
 
 
-import cgi
 try:
     from email.message import Message
 except ImportError:
@@ -38,6 +37,10 @@ import simplejson
 from StringIO import StringIO
 import types
 import urllib
+try:
+    from urlparse import parse_qs
+except ImportError:
+    from cgi import parse_qs
 from urlparse import urlparse, urljoin
 
 from lazr.uri import URI
@@ -586,8 +589,13 @@ class NamedOperation(RestfulBase):
         else:
             if http_method == 'post':
                 # The method call probably modified this resource in
-                # an unknown way. Refresh its representation.
-                self.resource.lp_refresh()
+                # an unknown way. If it moved to a new location, reload it or
+                # else just refresh its representation.
+                if response.status == 301:
+                    url = response['location']
+                    response, content = self.root._browser._request(url)
+                else:
+                    self.resource.lp_refresh()
             return self._handle_200_response(url, response, content)
 
     def _handle_201_response(self, url, response, content):
@@ -927,7 +935,7 @@ class Collection(Resource):
         if uri.query is None:
             params = {}
         else:
-            params = cgi.parse_qs(uri.query)
+            params = parse_qs(uri.query)
         params[variable] = str(new_value)
         uri.query = urllib.urlencode(params, True)
         return str(uri)
