@@ -34,6 +34,8 @@ class CookbookSet(CollectionWithKeyBasedLookup):
         return (str(self._root._root_uri.ensureSlash())
                 + 'cookbooks/' + quote(str(id)))
 
+    collection_of = "cookbook"
+
 
 class RecipeSet(CollectionWithKeyBasedLookup):
     """A custom subclass capable of recipe lookup by recipe ID."""
@@ -42,6 +44,8 @@ class RecipeSet(CollectionWithKeyBasedLookup):
         """Transform a recipe ID into the URL to a recipe resource."""
         return str(self._root._root_uri.ensureSlash()) + 'recipes/' + str(id)
 
+    collection_of = "recipe"
+
 
 class CookbookWebServiceClient(ServiceRoot):
 
@@ -49,7 +53,10 @@ class CookbookWebServiceClient(ServiceRoot):
     RESOURCE_TYPE_CLASSES['recipes'] = RecipeSet
     RESOURCE_TYPE_CLASSES['cookbooks'] = CookbookSet
 
-    def __init__(self, service_root="http://cookbooks.dev/", version='1.0',
-                 cache=None):
+    DEFAULT_SERVICE_ROOT = "http://cookbooks.dev/"
+    DEFAULT_VERSION = "1.0"
+
+    def __init__(self, service_root=DEFAULT_SERVICE_ROOT,
+                 version=DEFAULT_VERSION, cache=None):
         super(CookbookWebServiceClient, self).__init__(
             None, service_root, cache=cache, version=version)
